package
Version:
v0.0.0-...-0d9eda9
Opens a new window with list of versions in this module.
Published: Nov 23, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User struct {
*gorm.Model
Name string `gorm:"not null"`
Email string `gorm:"unique; not null"`
Password string `gorm:"not null"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.